@@ -16,32 +16,33 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.secretmanager_v1.services.secret_manager_service import pagers
-from google.cloud.secretmanager_v1.types import resources
-from google.cloud.secretmanager_v1.types import service
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import SecretManagerServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import SecretManagerServiceGrpcAsyncIOTransport
+
+from google.cloud.secretmanager_v1.services.secret_manager_service import pagers
+from google.cloud.secretmanager_v1.types import resources, service
+
 from .client import SecretManagerServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, SecretManagerServiceTransport
+from .transports.grpc_asyncio import SecretManagerServiceGrpcAsyncIOTransport
 
 
 class SecretManagerServiceAsyncClient:
@@ -237,9 +238,9 @@ class SecretManagerServiceAsyncClient:
 
             from google.cloud import secretmanager_v1
 
-            def sample_list_secrets():
+            async def sample_list_secrets():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.ListSecretsRequest(
@@ -250,7 +251,7 @@ class SecretManagerServiceAsyncClient:
                 page_result = client.list_secrets(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -347,14 +348,13 @@ class SecretManagerServiceAsyncClient:
         containing no
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_create_secret():
+            async def sample_create_secret():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.CreateSecretRequest(
@@ -363,7 +363,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_secret(request=request)
+                response = await client.create_secret(request=request)
 
                 # Handle the response
                 print(response)
@@ -477,14 +477,13 @@ class SecretManagerServiceAsyncClient:
         containing secret data and attaches it to an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_add_secret_version():
+            async def sample_add_secret_version():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.AddSecretVersionRequest(
@@ -492,7 +491,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.add_secret_version(request=request)
+                response = await client.add_secret_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -586,14 +585,13 @@ class SecretManagerServiceAsyncClient:
         r"""Gets metadata for a given
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_get_secret():
+            async def sample_get_secret():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.GetSecretRequest(
@@ -601,7 +599,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_secret(request=request)
+                response = await client.get_secret(request=request)
 
                 # Handle the response
                 print(response)
@@ -690,21 +688,20 @@ class SecretManagerServiceAsyncClient:
         r"""Updates metadata of an existing
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_update_secret():
+            async def sample_update_secret():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.UpdateSecretRequest(
                 )
 
                 # Make the request
-                response = client.update_secret(request=request)
+                response = await client.update_secret(request=request)
 
                 # Handle the response
                 print(response)
@@ -805,9 +802,9 @@ class SecretManagerServiceAsyncClient:
 
             from google.cloud import secretmanager_v1
 
-            def sample_delete_secret():
+            async def sample_delete_secret():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.DeleteSecretRequest(
@@ -815,7 +812,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_secret(request=request)
+                await client.delete_secret(request=request)
 
         Args:
             request (Union[google.cloud.secretmanager_v1.types.DeleteSecretRequest, dict]):
@@ -887,14 +884,13 @@ class SecretManagerServiceAsyncClient:
         [SecretVersions][google.cloud.secretmanager.v1.SecretVersion].
         This call does not return secret data.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_list_secret_versions():
+            async def sample_list_secret_versions():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.ListSecretVersionsRequest(
@@ -905,7 +901,7 @@ class SecretManagerServiceAsyncClient:
                 page_result = client.list_secret_versions(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1004,14 +1000,13 @@ class SecretManagerServiceAsyncClient:
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_get_secret_version():
+            async def sample_get_secret_version():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.GetSecretVersionRequest(
@@ -1019,7 +1014,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_secret_version(request=request)
+                response = await client.get_secret_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -1111,14 +1106,13 @@ class SecretManagerServiceAsyncClient:
         recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_access_secret_version():
+            async def sample_access_secret_version():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.AccessSecretVersionRequest(
@@ -1126,7 +1120,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.access_secret_version(request=request)
+                response = await client.access_secret_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -1229,14 +1223,13 @@ class SecretManagerServiceAsyncClient:
         to
         [DISABLED][google.cloud.secretmanager.v1.SecretVersion.State.DISABLED].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_disable_secret_version():
+            async def sample_disable_secret_version():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.DisableSecretVersionRequest(
@@ -1244,7 +1237,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.disable_secret_version(request=request)
+                response = await client.disable_secret_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -1334,14 +1327,13 @@ class SecretManagerServiceAsyncClient:
         to
         [ENABLED][google.cloud.secretmanager.v1.SecretVersion.State.ENABLED].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_enable_secret_version():
+            async def sample_enable_secret_version():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.EnableSecretVersionRequest(
@@ -1349,7 +1341,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.enable_secret_version(request=request)
+                response = await client.enable_secret_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -1440,14 +1432,13 @@ class SecretManagerServiceAsyncClient:
         [DESTROYED][google.cloud.secretmanager.v1.SecretVersion.State.DESTROYED]
         and irrevocably destroys the secret data.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
 
-            def sample_destroy_secret_version():
+            async def sample_destroy_secret_version():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = secretmanager_v1.DestroySecretVersionRequest(
@@ -1455,7 +1446,7 @@ class SecretManagerServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.destroy_secret_version(request=request)
+                response = await client.destroy_secret_version(request=request)
 
                 # Handle the response
                 print(response)
@@ -1543,22 +1534,22 @@ class SecretManagerServiceAsyncClient:
         are enforced according to the policy set on the associated
         [Secret][google.cloud.secretmanager.v1.Secret].
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_set_iam_policy():
+            async def sample_set_iam_policy():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = secretmanager_v1.SetIamPolicyRequest(
+                request = iam_policy_pb2.SetIamPolicyRequest(
                     resource="resource_value",
                 )
 
                 # Make the request
-                response = client.set_iam_policy(request=request)
+                response = await client.set_iam_policy(request=request)
 
                 # Handle the response
                 print(response)
@@ -1575,21 +1566,26 @@ class SecretManagerServiceAsyncClient:
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1604,17 +1600,17 @@ class SecretManagerServiceAsyncClient:
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1625,11 +1621,12 @@ class SecretManagerServiceAsyncClient:
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -1675,22 +1672,22 @@ class SecretManagerServiceAsyncClient:
         Returns empty policy if the secret exists and does not
         have a policy set.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_get_iam_policy():
+            async def sample_get_iam_policy():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = secretmanager_v1.GetIamPolicyRequest(
+                request = iam_policy_pb2.GetIamPolicyRequest(
                     resource="resource_value",
                 )
 
                 # Make the request
-                response = client.get_iam_policy(request=request)
+                response = await client.get_iam_policy(request=request)
 
                 # Handle the response
                 print(response)
@@ -1707,21 +1704,26 @@ class SecretManagerServiceAsyncClient:
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -1736,17 +1738,17 @@ class SecretManagerServiceAsyncClient:
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -1757,11 +1759,12 @@ class SecretManagerServiceAsyncClient:
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -1812,23 +1815,23 @@ class SecretManagerServiceAsyncClient:
         authorization checking. This operation may "fail open" without
         warning.
 
-
         .. code-block:: python
 
             from google.cloud import secretmanager_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_test_iam_permissions():
+            async def sample_test_iam_permissions():
                 # Create a client
-                client = secretmanager_v1.SecretManagerServiceClient()
+                client = secretmanager_v1.SecretManagerServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = secretmanager_v1.TestIamPermissionsRequest(
+                request = iam_policy_pb2.TestIamPermissionsRequest(
                     resource="resource_value",
                     permissions=['permissions_value_1', 'permissions_value_2'],
                 )
 
                 # Make the request
-                response = client.test_iam_permissions(request=request)
+                response = await client.test_iam_permissions(request=request)
 
                 # Handle the response
                 print(response)
