@@ -17,20 +17,18 @@
 
 import abc
 import typing
-import pkg_resources
 
-from google import auth  # type: ignore
 from google.api_core import exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials  # type: ignore
-
-from google.cloud.secretmanager_v1beta1.types import resources
-from google.cloud.secretmanager_v1beta1.types import service
 from google.iam.v1 import iam_policy_pb2 as iam_policy  # type: ignore
 from google.iam.v1 import policy_pb2 as policy  # type: ignore
 from google.protobuf import empty_pb2 as empty  # type: ignore
+import pkg_resources
 
+from google import auth  # type: ignore
+from google.cloud.secretmanager_v1beta1.types import resources, service
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
